==> kubernetes-model-autoscaling-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HorizontalPodAutoscalerBehaviorFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HorizontalPodAutoscalerBehaviorFluentImpl<A extends HorizontalPodAutoscalerBehaviorFluent<A>> extends BaseFluent<A> implements HorizontalPodAutoscalerBehaviorFluent<A>{
  public HorizontalPodAutoscalerBehaviorFluentImpl() {
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl(HorizontalPodAutoscalerBehavior instance) {
    this.withScaleDown(instance.getScaleDown()); 
    this.withScaleUp(instance.getScaleUp()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private HPAScalingRulesBuilder scaleDown;
  private HPAScalingRulesBuilder scaleUp;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildScaleDown instead.
   * @return The buildable object.
   */
  @Deprecated
  public HPAScalingRules getScaleDown() {
    return this.scaleDown!=null ?this.scaleDown.build():null;
  }
  public HPAScalingRules buildScaleDown() {
    return this.scaleDown!=null ?this.scaleDown.build():null;
  }
  public A withScaleDown(HPAScalingRules scaleDown) {
    _visitables.get("scaleDown").remove(this.scaleDown);
    if (scaleDown!=null){ this.scaleDown= new HPAScalingRulesBuilder(scaleDown); _visitables.get("scaleDown").add(this.scaleDown);} else { this.scaleDown = null; _visitables.get("scaleDown").remove(this.scaleDown); } return (A) this;
  }
  public Boolean hasScaleDown() {
    return this.scaleDown != null;
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> withNewScaleDown() {
    return new HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNestedImpl();
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> withNewScaleDownLike(HPAScalingRules item) {
    return new HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNestedImpl(item);
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editScaleDown() {
    return withNewScaleDownLike(getScaleDown());
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editOrNewScaleDown() {
    return withNewScaleDownLike(getScaleDown() != null ? getScaleDown(): new HPAScalingRulesBuilder().build());
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editOrNewScaleDownLike(HPAScalingRules item) {
    return withNewScaleDownLike(getScaleDown() != null ? getScaleDown(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildScaleUp instead.
   * @return The buildable object.
   */
  @Deprecated
  public HPAScalingRules getScaleUp() {
    return this.scaleUp!=null ?this.scaleUp.build():null;
  }
  public HPAScalingRules buildScaleUp() {
    return this.scaleUp!=null ?this.scaleUp.build():null;
  }
  public A withScaleUp(HPAScalingRules scaleUp) {
    _visitables.get("scaleUp").remove(this.scaleUp);
    if (scaleUp!=null){ this.scaleUp= new HPAScalingRulesBuilder(scaleUp); _visitables.get("scaleUp").add(this.scaleUp);} else { this.scaleUp = null; _visitables.get("scaleUp").remove(this.scaleUp); } return (A) this;
  }
  public Boolean hasScaleUp() {
    return this.scaleUp != null;
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> withNewScaleUp() {
    return new HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNestedImpl();
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> withNewScaleUpLike(HPAScalingRules item) {
    return new HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNestedImpl(item);
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editScaleUp() {
    return withNewScaleUpLike(getScaleUp());
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editOrNewScaleUp() {
    return withNewScaleUpLike(getScaleUp() != null ? getScaleUp(): new HPAScalingRulesBuilder().build());
  }
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editOrNewScaleUpLike(HPAScalingRules item) {
    return withNewScaleUpLike(getScaleUp() != null ? getScaleUp(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HorizontalPodAutoscalerBehaviorFluentImpl that = (HorizontalPodAutoscalerBehaviorFluentImpl) o;
    if (scaleDown != null ? !scaleDown.equals(that.scaleDown) :that.scaleDown != null) return false;
    if (scaleUp != null ? !scaleUp.equals(that.scaleUp) :that.scaleUp != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(scaleDown,  scaleUp,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (scaleDown != null) { sb.append("scaleDown:"); sb.append(scaleDown + ","); }
    if (scaleUp != null) { sb.append("scaleUp:"); sb.append(scaleUp + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ScaleDownNestedImpl<N> extends HPAScalingRulesFluentImpl<HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<N>> implements HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<N>,Nested<N>{
    ScaleDownNestedImpl(HPAScalingRules item) {
      this.builder = new HPAScalingRulesBuilder(this, item);
    }
    ScaleDownNestedImpl() {
      this.builder = new HPAScalingRulesBuilder(this);
    }
    HPAScalingRulesBuilder builder;
    public N and() {
      return (N) HorizontalPodAutoscalerBehaviorFluentImpl.this.withScaleDown(builder.build());
    }
    public N endScaleDown() {
      return and();
    }
    
  }
  class ScaleUpNestedImpl<N> extends HPAScalingRulesFluentImpl<HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<N>> implements HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<N>,Nested<N>{
    ScaleUpNestedImpl(HPAScalingRules item) {
      this.builder = new HPAScalingRulesBuilder(this, item);
    }
    ScaleUpNestedImpl() {
      this.builder = new HPAScalingRulesBuilder(this);
    }
    HPAScalingRulesBuilder builder;
    public N and() {
      return (N) HorizontalPodAutoscalerBehaviorFluentImpl.this.withScaleUp(builder.build());
    }
    public N endScaleUp() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HorizontalPodAutoscalerBehaviorFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HorizontalPodAutoscalerBehaviorFluentImpl<A extends HorizontalPodAutoscalerBehaviorFluent<A>> extends BaseFluent<A> implements HorizontalPodAutoscalerBehaviorFluent<A>{
  public HorizontalPodAutoscalerBehaviorFluentImpl() {
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl(HorizontalPodAutoscalerBehavior instance) {
    if (instance != null) {
      this.withScaleDown(instance.getScaleDown());
      this.withScaleUp(instance.getScaleUp());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private HPAScalingRulesBuilder scaleDown;
  private HPAScalingRulesBuilder scaleUp;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildScaleDown instead.
   * @return The buildable object.
   */
  @Deprecated
  public HPAScalingRules getScaleDown() {
    return this.scaleDown!=null ?this.scaleDown.build():null;
  }
  public HPAScalingRules buildScaleDown() {
    return this.scaleDown!=null ?this.scaleDown.build():null;
  }
  public A withScaleDown(HPAScalingRules scaleDown) {
    _visitables.get("scaleDown").remove(this.scaleDown);
    if (scaleDown!=null){ this.scaleDown= new HPAScalingRulesBuilder(scaleDown); _visitables.get("scaleDown").add(this.scaleDown);} else { this.scaleDown = null; _visitables.get("scaleDown").remove(this.scaleDown); } return (A) this;
  }
  public Boolean hasScaleDown() {
    return this.scaleDown != null;
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNested<A> withNewScaleDown() {
    return new HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNestedImpl();
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNested<A> withNewScaleDownLike(HPAScalingRules item) {
    return new HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNestedImpl(item);
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNested<A> editScaleDown() {
    return withNewScaleDownLike(getScaleDown());
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNested<A> editOrNewScaleDown() {
    return withNewScaleDownLike(getScaleDown() != null ? getScaleDown(): new HPAScalingRulesBuilder().build());
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNested<A> editOrNewScaleDownLike(HPAScalingRules item) {
    return withNewScaleDownLike(getScaleDown() != null ? getScaleDown(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildScaleUp instead.
   * @return The buildable object.
   */
  @Deprecated
  public HPAScalingRules getScaleUp() {
    return this.scaleUp!=null ?this.scaleUp.build():null;
  }
  public HPAScalingRules buildScaleUp() {
    return this.scaleUp!=null ?this.scaleUp.build():null;
  }
  public A withScaleUp(HPAScalingRules scaleUp) {
    _visitables.get("scaleUp").remove(this.scaleUp);
    if (scaleUp!=null){ this.scaleUp= new HPAScalingRulesBuilder(scaleUp); _visitables.get("scaleUp").add(this.scaleUp);} else { this.scaleUp = null; _visitables.get("scaleUp").remove(this.scaleUp); } return (A) this;
  }
  public Boolean hasScaleUp() {
    return this.scaleUp != null;
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNested<A> withNewScaleUp() {
    return new HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNestedImpl();
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNested<A> withNewScaleUpLike(HPAScalingRules item) {
    return new HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNestedImpl(item);
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNested<A> editScaleUp() {
    return withNewScaleUpLike(getScaleUp());
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNested<A> editOrNewScaleUp() {
    return withNewScaleUpLike(getScaleUp() != null ? getScaleUp(): new HPAScalingRulesBuilder().build());
  }
  public HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNested<A> editOrNewScaleUpLike(HPAScalingRules item) {
    return withNewScaleUpLike(getScaleUp() != null ? getScaleUp(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HorizontalPodAutoscalerBehaviorFluentImpl that = (HorizontalPodAutoscalerBehaviorFluentImpl) o;
    if (!java.util.Objects.equals(scaleDown, that.scaleDown)) return false;

    if (!java.util.Objects.equals(scaleUp, that.scaleUp)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(scaleDown,  scaleUp,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (scaleDown != null) { sb.append("scaleDown:"); sb.append(scaleDown + ","); }
    if (scaleUp != null) { sb.append("scaleUp:"); sb.append(scaleUp + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ScaleDownNestedImpl<N> extends HPAScalingRulesFluentImpl<HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNested<N>> implements HorizontalPodAutoscalerBehaviorFluentImpl.ScaleDownNested<N>,Nested<N>{
    ScaleDownNestedImpl(HPAScalingRules item) {
      this.builder = new HPAScalingRulesBuilder(this, item);
    }
    ScaleDownNestedImpl() {
      this.builder = new HPAScalingRulesBuilder(this);
    }
    HPAScalingRulesBuilder builder;
    public N and() {
      return (N) HorizontalPodAutoscalerBehaviorFluentImpl.this.withScaleDown(builder.build());
    }
    public N endScaleDown() {
      return and();
    }
    
  }
  class ScaleUpNestedImpl<N> extends HPAScalingRulesFluentImpl<HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNested<N>> implements HorizontalPodAutoscalerBehaviorFluentImpl.ScaleUpNested<N>,Nested<N>{
    ScaleUpNestedImpl(HPAScalingRules item) {
      this.builder = new HPAScalingRulesBuilder(this, item);
    }
    ScaleUpNestedImpl() {
      this.builder = new HPAScalingRulesBuilder(this);
    }
    HPAScalingRulesBuilder builder;
    public N and() {
      return (N) HorizontalPodAutoscalerBehaviorFluentImpl.this.withScaleUp(builder.build());
    }
    public N endScaleUp() {
      return and();
    }
    
  }
  
}
